==> openshift-model-operator-5.10.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/LoggingDestinationFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class LoggingDestinationFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluent<A>{
  public LoggingDestinationFluentImpl() {
  }
  public LoggingDestinationFluentImpl(io.fabric8.openshift.api.model.operator.v1.LoggingDestination instance) {
    this.withContainer(instance.getContainer()); 
    this.withSyslog(instance.getSyslog()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.operator.v1.ContainerLoggingDestinationParametersBuilder container;
  private io.fabric8.openshift.api.model.operator.v1.SyslogLoggingDestinationParametersBuilder syslog;
  private java.lang.String type;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildContainer instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.ContainerLoggingDestinationParameters getContainer() {
    return this.container!=null?this.container.build():null;
  }
  public io.fabric8.openshift.api.model.operator.v1.ContainerLoggingDestinationParameters buildContainer() {
    return this.container!=null?this.container.build():null;
  }
  public A withContainer(io.fabric8.openshift.api.model.operator.v1.ContainerLoggingDestinationParameters container) {
    _visitables.get("container").remove(this.container);
    if (container!=null){ this.container= new io.fabric8.openshift.api.model.operator.v1.ContainerLoggingDestinationParametersBuilder(container); _visitables.get("container").add(this.container);} return (A) this;
  }
  public java.lang.Boolean hasContainer() {
    return this.container != null;
  }
  public io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluent.ContainerNested<A> withNewContainer() {
    return new io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluentImpl.ContainerNestedImpl();
  }
  public io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluent.ContainerNested<A> withNewContainerLike(io.fabric8.openshift.api.model.operator.v1.ContainerLoggingDestinationParameters item) {
    return new io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluentImpl.ContainerNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluent.ContainerNested<A> editContainer() {
    return withNewContainerLike(getContainer());
  }
  public io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluent.ContainerNested<A> editOrNewContainer() {
    return withNewContainerLike(getContainer() != null ? getContainer(): new io.fabric8.openshift.api.model.operator.v1.ContainerLoggingDestinationParametersBuilder().build());
  }
  public io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluent.ContainerNested<A> editOrNewContainerLike(io.fabric8.openshift.api.model.operator.v1.ContainerLoggingDestinationParameters item) {
    return withNewContainerLike(getContainer() != null ? getContainer(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSyslog instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.SyslogLoggingDestinationParameters getSyslog() {
    return this.syslog!=null?this.syslog.build():null;
  }
  public io.fabric8.openshift.api.model.operator.v1.SyslogLoggingDestinationParameters buildSyslog() {
    return this.syslog!=null?this.syslog.build():null;
  }
  public A withSyslog(io.fabric8.openshift.api.model.operator.v1.SyslogLoggingDestinationParameters syslog) {
    _visitables.get("syslog").remove(this.syslog);
    if (syslog!=null){ this.syslog= new io.fabric8.openshift.api.model.operator.v1.SyslogLoggingDestinationParametersBuilder(syslog); _visitables.get("syslog").add(this.syslog);} return (A) this;
  }
  public java.lang.Boolean hasSyslog() {
    return this.syslog != null;
  }
  public A withNewSyslog(java.lang.String address,java.lang.String facility,java.lang.Integer port) {
    return (A)withSyslog(new SyslogLoggingDestinationParameters(address, facility, port));
  }
  public io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluent.SyslogNested<A> withNewSyslog() {
    return new io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluentImpl.SyslogNestedImpl();
  }
  public io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluent.SyslogNested<A> withNewSyslogLike(io.fabric8.openshift.api.model.operator.v1.SyslogLoggingDestinationParameters item) {
    return new io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluentImpl.SyslogNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluent.SyslogNested<A> editSyslog() {
    return withNewSyslogLike(getSyslog());
  }
  public io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluent.SyslogNested<A> editOrNewSyslog() {
    return withNewSyslogLike(getSyslog() != null ? getSyslog(): new io.fabric8.openshift.api.model.operator.v1.SyslogLoggingDestinationParametersBuilder().build());
  }
  public io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluent.SyslogNested<A> editOrNewSyslogLike(io.fabric8.openshift.api.model.operator.v1.SyslogLoggingDestinationParameters item) {
    return withNewSyslogLike(getSyslog() != null ? getSyslog(): item);
  }
  public java.lang.String getType() {
    return this.type;
  }
  public A withType(java.lang.String type) {
    this.type=type; return (A) this;
  }
  public java.lang.Boolean hasType() {
    return this.type != null;
  }
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0) {
    return (A)withType(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    LoggingDestinationFluentImpl that = (LoggingDestinationFluentImpl) o;
    if (container != null ? !container.equals(that.container) :that.container != null) return false;
    if (syslog != null ? !syslog.equals(that.syslog) :that.syslog != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(container,  syslog,  type,  additionalProperties,  super.hashCode());
  }
  public class ContainerNestedImpl<N> extends io.fabric8.openshift.api.model.operator.v1.ContainerLoggingDestinationParametersFluentImpl<io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluent.ContainerNested<N>> implements io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluent.ContainerNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ContainerNestedImpl(io.fabric8.openshift.api.model.operator.v1.ContainerLoggingDestinationParameters item) {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.ContainerLoggingDestinationParametersBuilder(this, item);
    }
    ContainerNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.ContainerLoggingDestinationParametersBuilder(this);
    }
    io.fabric8.openshift.api.model.operator.v1.ContainerLoggingDestinationParametersBuilder builder;
    public N and() {
      return (N) LoggingDestinationFluentImpl.this.withContainer(builder.build());
    }
    public N endContainer() {
      return and();
    }
    
  }
  public class SyslogNestedImpl<N> extends io.fabric8.openshift.api.model.operator.v1.SyslogLoggingDestinationParametersFluentImpl<io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluent.SyslogNested<N>> implements io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluent.SyslogNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    SyslogNestedImpl(io.fabric8.openshift.api.model.operator.v1.SyslogLoggingDestinationParameters item) {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.SyslogLoggingDestinationParametersBuilder(this, item);
    }
    SyslogNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.SyslogLoggingDestinationParametersBuilder(this);
    }
    io.fabric8.openshift.api.model.operator.v1.SyslogLoggingDestinationParametersBuilder builder;
    public N and() {
      return (N) LoggingDestinationFluentImpl.this.withSyslog(builder.build());
    }
    public N endSyslog() {
      return and();
    }
    
  }
  
}

==> openshift-model-operator-5.11.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/LoggingDestinationFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class LoggingDestinationFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluent<A>{
  public LoggingDestinationFluentImpl() {
  }
  public LoggingDestinationFluentImpl(io.fabric8.openshift.api.model.operator.v1.LoggingDestination instance) {
    this.withContainer(instance.getContainer()); 
    this.withSyslog(instance.getSyslog()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.operator.v1.ContainerLoggingDestinationParametersBuilder container;
  private io.fabric8.openshift.api.model.operator.v1.SyslogLoggingDestinationParametersBuilder syslog;
  private java.lang.String type;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildContainer instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.ContainerLoggingDestinationParameters getContainer() {
    return this.container!=null?this.container.build():null;
  }
  public io.fabric8.openshift.api.model.operator.v1.ContainerLoggingDestinationParameters buildContainer() {
    return this.container!=null?this.container.build():null;
  }
  public A withContainer(io.fabric8.openshift.api.model.operator.v1.ContainerLoggingDestinationParameters container) {
    _visitables.get("container").remove(this.container);
    if (container!=null){ this.container= new io.fabric8.openshift.api.model.operator.v1.ContainerLoggingDestinationParametersBuilder(container); _visitables.get("container").add(this.container);} return (A) this;
  }
  public java.lang.Boolean hasContainer() {
    return this.container != null;
  }
  public io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluent.ContainerNested<A> withNewContainer() {
    return new io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluentImpl.ContainerNestedImpl();
  }
  public io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluent.ContainerNested<A> withNewContainerLike(io.fabric8.openshift.api.model.operator.v1.ContainerLoggingDestinationParameters item) {
    return new io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluentImpl.ContainerNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluent.ContainerNested<A> editContainer() {
    return withNewContainerLike(getContainer());
  }
  public io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluent.ContainerNested<A> editOrNewContainer() {
    return withNewContainerLike(getContainer() != null ? getContainer(): new io.fabric8.openshift.api.model.operator.v1.ContainerLoggingDestinationParametersBuilder().build());
  }
  public io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluent.ContainerNested<A> editOrNewContainerLike(io.fabric8.openshift.api.model.operator.v1.ContainerLoggingDestinationParameters item) {
    return withNewContainerLike(getContainer() != null ? getContainer(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSyslog instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.SyslogLoggingDestinationParameters getSyslog() {
    return this.syslog!=null?this.syslog.build():null;
  }
  public io.fabric8.openshift.api.model.operator.v1.SyslogLoggingDestinationParameters buildSyslog() {
    return this.syslog!=null?this.syslog.build():null;
  }
  public A withSyslog(io.fabric8.openshift.api.model.operator.v1.SyslogLoggingDestinationParameters syslog) {
    _visitables.get("syslog").remove(this.syslog);
    if (syslog!=null){ this.syslog= new io.fabric8.openshift.api.model.operator.v1.SyslogLoggingDestinationParametersBuilder(syslog); _visitables.get("syslog").add(this.syslog);} return (A) this;
  }
  public java.lang.Boolean hasSyslog() {
    return this.syslog != null;
  }
  public A withNewSyslog(java.lang.String address,java.lang.String facility,java.lang.Integer maxLength,java.lang.Integer port) {
    return (A)withSyslog(new SyslogLoggingDestinationParameters(address, facility, maxLength, port));
  }
  public io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluent.SyslogNested<A> withNewSyslog() {
    return new io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluentImpl.SyslogNestedImpl();
  }
  public io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluent.SyslogNested<A> withNewSyslogLike(io.fabric8.openshift.api.model.operator.v1.SyslogLoggingDestinationParameters item) {
    return new io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluentImpl.SyslogNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluent.SyslogNested<A> editSyslog() {
    return withNewSyslogLike(getSyslog());
  }
  public io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluent.SyslogNested<A> editOrNewSyslog() {
    return withNewSyslogLike(getSyslog() != null ? getSyslog(): new io.fabric8.openshift.api.model.operator.v1.SyslogLoggingDestinationParametersBuilder().build());
  }
  public io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluent.SyslogNested<A> editOrNewSyslogLike(io.fabric8.openshift.api.model.operator.v1.SyslogLoggingDestinationParameters item) {
    return withNewSyslogLike(getSyslog() != null ? getSyslog(): item);
  }
  public java.lang.String getType() {
    return this.type;
  }
  public A withType(java.lang.String type) {
    this.type=type; return (A) this;
  }
  public java.lang.Boolean hasType() {
    return this.type != null;
  }
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0) {
    return (A)withType(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    LoggingDestinationFluentImpl that = (LoggingDestinationFluentImpl) o;
    if (container != null ? !container.equals(that.container) :that.container != null) return false;
    if (syslog != null ? !syslog.equals(that.syslog) :that.syslog != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(container,  syslog,  type,  additionalProperties,  super.hashCode());
  }
  public class ContainerNestedImpl<N> extends io.fabric8.openshift.api.model.operator.v1.ContainerLoggingDestinationParametersFluentImpl<io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluent.ContainerNested<N>> implements io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluent.ContainerNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ContainerNestedImpl(io.fabric8.openshift.api.model.operator.v1.ContainerLoggingDestinationParameters item) {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.ContainerLoggingDestinationParametersBuilder(this, item);
    }
    ContainerNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.ContainerLoggingDestinationParametersBuilder(this);
    }
    io.fabric8.openshift.api.model.operator.v1.ContainerLoggingDestinationParametersBuilder builder;
    public N and() {
      return (N) LoggingDestinationFluentImpl.this.withContainer(builder.build());
    }
    public N endContainer() {
      return and();
    }
    
  }
  public class SyslogNestedImpl<N> extends io.fabric8.openshift.api.model.operator.v1.SyslogLoggingDestinationParametersFluentImpl<io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluent.SyslogNested<N>> implements io.fabric8.openshift.api.model.operator.v1.LoggingDestinationFluent.SyslogNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    SyslogNestedImpl(io.fabric8.openshift.api.model.operator.v1.SyslogLoggingDestinationParameters item) {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.SyslogLoggingDestinationParametersBuilder(this, item);
    }
    SyslogNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.SyslogLoggingDestinationParametersBuilder(this);
    }
    io.fabric8.openshift.api.model.operator.v1.SyslogLoggingDestinationParametersBuilder builder;
    public N and() {
      return (N) LoggingDestinationFluentImpl.this.withSyslog(builder.build());
    }
    public N endSyslog() {
      return and();
    }
    
  }
  
}
